# Flask-Avatars
All avatar generators in one place:

* Default avatar
* Gravatar
* Robohash
* Social media avatar
* Identicon generation
* Avatar crop

## Links

* Documentation: https://flask-avatars.readthedocs.io/en/latest/
* PyPI: https://pypi.org/project/Flask-Avatars/

## License

This project is licensed under the MIT License (see the
`LICENSE` file for details).
